@@ -8,31 +8,20 @@ use warnings;
 use Carp;
 use Test::More 0.88;
 
-use Exporter;
-our @ISA = qw{ Exporter };
+use base qw{ Exporter };
 
-no if "$]" >= 5.020, feature => qw{ signatures };
-
-# This occurs in both inc/My/Module/Meta.pm and inc/My/Module/Test.pm
-use constant CAN_USE_UNICODE	=> "$]" >= 5.008004;
-
-our $VERSION = '0.104_01';
+our $VERSION = '0.008';
 
 our @EXPORT =		## no critic (ProhibitAutomaticExportation)
 qw{
     check_testable
     do_utf
-    hex_diag
     pb_name
     pb_opt
     pb_putter
-    set_test_output_encoding
     test_vs_pbpaste
-    CAN_USE_UNICODE
 };
 
-use constant REF_ARRAY	=> ref [];
-
 sub check_testable (;$) {	## no critic (ProhibitSubroutinePrototypes)
     my ( $prog ) = @_;
 
@@ -72,28 +61,6 @@ sub check_testable (;$) {	## no critic (ProhibitSubroutinePrototypes)
     }
 }
 
-sub hex_diag ($;$) {
-    my ( $got, $expect ) = @_;
-    foreach (
-	[ got => $got ],
-	( @_ > 1 ? [ expected => $expect ] : () ),
-    ) {
-	my ( $name, $value ) = @{ $_ };
-	my $hex = do {
-	    use bytes;
-	    unpack 'H*', $value;
-	};
-	$hex =~ s/ ( .. ) /$1 /smxg;
-	$hex =~ s/ \s+ \z //smx;
-	diag sprintf '%12s: %s', $name, $hex;
-	if ( $ENV{DEVELOPER_DEBUG} ) {
-	    require Devel::Peek;
-	    Devel::Peek::Dump( $value );
-	}
-    }
-    return;
-}
-
 sub pb_name ($) {	## no critic (ProhibitSubroutinePrototypes, RequireArgUnpacking)
     $_[1] = 'name';
     goto &_pb_info;
@@ -135,67 +102,16 @@ sub pb_putter ($) {	## no critic (ProhibitSubroutinePrototypes, RequireArgUnpack
     }
 }
 
-sub set_test_output_encoding (;$) {	## no critic (ProhibitSubroutinePrototypes)
-    my ( $encoding ) = @_;
-    CAN_USE_UNICODE
-	or return;
-    unless ( defined $encoding ) {
-	local $@ = undef;
-	eval {
-	    require I18N::Langinfo;
-	    $encoding = I18N::Langinfo::langinfo(
-		I18N::Langinfo::CODESET() );
-	    1;
-	} or $encoding = '';
-    }
-    defined $encoding
-	and '' ne $encoding
-	or return;
-    my $builder = Test::More->builder();
-    foreach ( qw{ output failure_output todo_output } ) {
-	_my_binmode( $builder->$_(), ":encoding($encoding)" )
-	    or confess "Failed to set Test::More $_ encoding to $encoding: $!";
-    }
-    return;
-}
-
-# I hate this, but Perl 5.6.2 does not have the two-argument binmode.
-if ( CAN_USE_UNICODE ) {
-    eval 'sub _my_binmode { binmode $_[0], $_[1] }';
-} else {
-    eval 'sub _my_binmode { 1 }';
-}
-
 sub test_vs_pbpaste ($$$) {	## no critic (ProhibitSubroutinePrototypes, RequireArgUnpacking)
     my ( $pbopt, $expect, $name ) = @_;
     my @cmd = qw{ pbpaste };
-    if ( defined $pbopt ) {
-	if ( REF_ARRAY eq ref $pbopt ) {
-	    push @cmd, @{ $pbopt };
-	} else {
-	    push @cmd, split qr< \s+ >smx, $pbopt;
-	}
-    }
     defined $pbopt
 	and push @cmd, $pbopt;
-    open my $fh, '-|', @cmd
-	or croak "Failed to open pipe from @cmd: $!";
-    # FIXME do I need to be more canny about this?
-    if ( CAN_USE_UNICODE ) {
-	_my_binmode( $fh, ':encoding(utf-8)' )
-	    or croak "Failed to set pipe from @cmd to utf-8: $!";
-    }
-    my $got = do {
-	local $/ = undef;
-	<$fh>;
-    };
-    close $fh;
+    my $got = `@cmd`;
     chomp $got;
     chomp $expect;
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
-    is $got, $expect, $name
-	and return 1;
-    return hex_diag( $got, $expect );
+    @_ = ( $got, $expect, $name );
+    goto &is;
 }
 
 1;
@@ -296,8 +212,7 @@ done by C<goto &Test::More::is>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-Mac-Pasteboard/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -305,7 +220,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2024 by Thomas R. Wyant, III
+Copyright (C) 2013-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
